fn fruits_get_footer_data() -> Vec<FooterData>Expand description
Should add an action to the Footer Data (like apply, move, change value).
fn fruits_get_footer_data() -> Vec<FooterData>Should add an action to the Footer Data (like apply, move, change value).